@@ -7,6 +7,7 @@ irrespective of what has been deposited with the U.S. Copyright Office.
 
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package main
 
@@ -18,19 +19,26 @@ import (
 	"strings"
 	"time"
 
-	"github.com/open-cluster-management/search-collector/pkg/config"
-	inform "github.com/open-cluster-management/search-collector/pkg/informer"
-	rec "github.com/open-cluster-management/search-collector/pkg/reconciler"
-	tr "github.com/open-cluster-management/search-collector/pkg/transforms"
+	"github.com/stolostron/search-collector/pkg/config"
+	inform "github.com/stolostron/search-collector/pkg/informer"
+	lease "github.com/stolostron/search-collector/pkg/lease"
+	rec "github.com/stolostron/search-collector/pkg/reconciler"
+	tr "github.com/stolostron/search-collector/pkg/transforms"
 
 	"github.com/golang/glog"
-	"github.com/open-cluster-management/search-collector/pkg/send"
+	"github.com/stolostron/search-collector/pkg/send"
 	machineryV1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime/schema"
+	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/client-go/discovery"
 )
 
+const (
+	AddonName            = "search-collector"
+	LeaseDurationSeconds = 60
+)
+
 func main() {
 	// init logs
 	flag.Parse()
@@ -47,11 +55,23 @@ func main() {
 	// so that we take maximum advantage of whatever hardware we're on
 	numThreads := runtime.NumCPU()
 
-	glog.Info("Starting Data Collector")
+	glog.Info("Starting Search Collector")
 	if commit, ok := os.LookupEnv("VCS_REF"); ok {
 		glog.Info("Built from git commit: ", commit)
 	}
 
+	if !config.Cfg.DeployedInHub {
+		leaseReconciler := lease.LeaseReconciler{
+			HubKubeClient:        config.GetKubeClient(config.Cfg.AggregatorConfig),
+			KubeClient:           config.GetKubeClient(config.GetKubeConfig()),
+			LeaseName:            AddonName,
+			ClusterName:          config.Cfg.ClusterName,
+			LeaseDurationSeconds: int32(LeaseDurationSeconds),
+		}
+		glog.Info("Create/Update lease for search")
+		go wait.Forever(leaseReconciler.Reconcile, time.Duration(leaseReconciler.LeaseDurationSeconds)*time.Second)
+	}
+
 	// Create input channel
 	transformChannel := make(chan *tr.Event)
 
@@ -65,9 +85,6 @@ func main() {
 	// Create Sender, attached to transformer
 	sender := send.NewSender(reconciler, config.Cfg.AggregatorURL, config.Cfg.ClusterName)
 
-	// Disabeling Helm client because it's no longer needed for Helm v3. Will remove once we confirm nothing is broken.
-	// tr.StartHelmClientProvider(transformChannel, config.GetKubeConfig())
-
 	// Get kubernetes client for discovering resource types
 	discoveryClient := config.GetDiscoveryClient()
 
@@ -109,17 +126,6 @@ func main() {
 			},
 		}
 		reconciler.Input <- ne
-
-		if tr.IsHelmRelease(resource) {
-			releaseNE := tr.NodeEvent{
-				Time:      time.Now().Unix(),
-				Operation: tr.Delete,
-				Node: tr.Node{
-					UID: tr.GetHelmReleaseUID(resource.GetLabels()["NAME"]),
-				},
-			}
-			reconciler.Input <- releaseNE
-		}
 	}
 
 	informersStarted := false
@@ -146,8 +152,8 @@ func main() {
 						delete(gvrList, gvr)
 						continue
 					} else { // if it's in the old and NOT in the new, stop the informer
-						stopper <- struct{}{}
-						glog.Infof("Resource %s no longer exists or no longer supports watch, stopping its informer\n", gvr.String())
+						glog.V(2).Infof("Resource %s no longer exists or no longer supports watch, stopping its informer\n", gvr.String())
+						close(stopper)
 						delete(stoppers, gvr)
 					}
 				}
@@ -176,7 +182,7 @@ func main() {
 		}
 	}()
 
-	glog.Info("Waiting for informers load initial state...")
+	glog.Info("Waiting for informers to load initial state...")
 	for !informersStarted {
 		time.Sleep(time.Duration(100) * time.Millisecond)
 	}
