@@ -6,6 +6,7 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package reconciler
 
@@ -19,7 +20,7 @@ import (
 
 	"github.com/golang/glog"
 	lru "github.com/golang/groupcache/lru"
-	tr "github.com/open-cluster-management/search-collector/pkg/transforms"
+	tr "github.com/stolostron/search-collector/pkg/transforms"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/helm/pkg/proto/hapi/release"
@@ -68,7 +69,6 @@ func createNodeEvents() []tr.NodeEvent {
 	p.Name = "testpod"
 	p.Kind = "Pod"
 	p.Namespace = "default"
-	p.SelfLink = "/api/v1/namespaces/default/pods/testpod"
 	p.UID = "5678"
 	podNode := tr.PodResourceBuilder(&p).BuildNode()
 	podNode.Metadata["OwnerUID"] = "local-cluster/1234"
@@ -378,8 +378,8 @@ func TestReconcilerComplete(t *testing.T) {
 	// Checks the count of nodes and edges based on the JSON files in pkg/test-data
 	// Update counts when the test data is changed
 	// We don't create Nodes for kind = Event
-	const Nodes = 31
-	const Edges = 34
+	const Nodes = 33
+	const Edges = 51
 	if len(com.Edges) != Edges || com.TotalEdges != Edges || len(com.Nodes) != Nodes || com.TotalNodes != Nodes {
 		ns := tr.NodeStore{
 			ByUID:               testReconciler.currentNodes,
