@@ -6,13 +6,14 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package transforms
 
 import (
 	"testing"
 
-	policy "github.com/open-cluster-management/governance-policy-propagator/pkg/apis/policies/v1"
+	policy "github.com/stolostron/governance-policy-propagator/pkg/apis/policy/v1"
 )
 
 func TestTransformPolicy(t *testing.T) {
